==> haskell-fourmolu-0.3.0.0-127-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fourmolu.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fourmolu
version:              0.3.0.0
visibility:           public
id:                   fourmolu-0.3.0.0-898M6dnnwPTIxFE4t2ltHt
key:                  fourmolu-0.3.0.0-898M6dnnwPTIxFE4t2ltHt
license:              BSD-3-Clause
maintainer:
    Matt Parsons <parsonsmatt@gmail.com>
    George Thomas <georgefsthomas@gmail.com>

homepage:             https://github.com/parsonsmatt/fourmolu
synopsis:             A formatter for Haskell source code
description:          A formatter for Haskell source code.
category:             Development, Formatting
abi:                  491a471638b22fc44779360e93e9a30b
exposed:              True
exposed-modules:
    Ormolu Ormolu.Config Ormolu.Diff Ormolu.Exception Ormolu.Imports
    Ormolu.Parser Ormolu.Parser.Anns Ormolu.Parser.CommentStream
    Ormolu.Parser.Pragma Ormolu.Parser.Result Ormolu.Parser.Shebang
    Ormolu.Printer Ormolu.Printer.Combinators Ormolu.Printer.Comments
    Ormolu.Printer.Internal Ormolu.Printer.Meat.Common
    Ormolu.Printer.Meat.Declaration
    Ormolu.Printer.Meat.Declaration.Annotation
    Ormolu.Printer.Meat.Declaration.Class
    Ormolu.Printer.Meat.Declaration.Data
    Ormolu.Printer.Meat.Declaration.Default
    Ormolu.Printer.Meat.Declaration.Foreign
    Ormolu.Printer.Meat.Declaration.Instance
    Ormolu.Printer.Meat.Declaration.RoleAnnotation
    Ormolu.Printer.Meat.Declaration.Rule
    Ormolu.Printer.Meat.Declaration.Signature
    Ormolu.Printer.Meat.Declaration.Splice
    Ormolu.Printer.Meat.Declaration.Type
    Ormolu.Printer.Meat.Declaration.TypeFamily
    Ormolu.Printer.Meat.Declaration.Value
    Ormolu.Printer.Meat.Declaration.Warning
    Ormolu.Printer.Meat.ImportExport Ormolu.Printer.Meat.Module
    Ormolu.Printer.Meat.Pragma Ormolu.Printer.Meat.Type
    Ormolu.Printer.Operators Ormolu.Printer.SpanStream
    Ormolu.Processing.Common Ormolu.Processing.Cpp
    Ormolu.Processing.Postprocess Ormolu.Processing.Preprocess
    Ormolu.Utils

hidden-modules:       GHC GHC.DynFlags
import-dirs:          /usr/lib/ghc-9.0.2/site-local/fourmolu-0.3.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/fourmolu-0.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/fourmolu-0.3.0.0
hs-libraries:         HSfourmolu-0.3.0.0-898M6dnnwPTIxFE4t2ltHt
depends:
    HsYAML-0.2.1.0-Fe6IxVDUBocHebbImmvbUD
    HsYAML-aeson-0.2.0.1-H9W8wEnbLAp7IPma7BTDd6
    aeson-1.5.6.0-3UkULX00zZS4WfonZkjdLx base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1 directory-1.3.6.2
    dlist-1.0-F00OxiD1dC249OyRKVGlo2 exceptions-0.10.4 filepath-1.4.2.1
    ghc-lib-parser-8.10.5.20210606-7jpwkYARfluCRNplNhV1BZ mtl-2.2.2
    syb-0.7.2.1-FjcIthMpdOC3Lvp3JeJE9F text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-fourmolu/html/fourmolu.haddock
haddock-html:         /usr/share/doc/haskell-fourmolu/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fourmolu-0.3.0.0-128-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fourmolu.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fourmolu
version:              0.3.0.0
visibility:           public
id:                   fourmolu-0.3.0.0-2WinoTX2cM7BgDXOxBMTee
key:                  fourmolu-0.3.0.0-2WinoTX2cM7BgDXOxBMTee
license:              BSD-3-Clause
maintainer:
    Matt Parsons <parsonsmatt@gmail.com>
    George Thomas <georgefsthomas@gmail.com>

homepage:             https://github.com/parsonsmatt/fourmolu
synopsis:             A formatter for Haskell source code
description:          A formatter for Haskell source code.
category:             Development, Formatting
abi:                  093642b711f5e67af67b2b35e99827b5
exposed:              True
exposed-modules:
    Ormolu Ormolu.Config Ormolu.Diff Ormolu.Exception Ormolu.Imports
    Ormolu.Parser Ormolu.Parser.Anns Ormolu.Parser.CommentStream
    Ormolu.Parser.Pragma Ormolu.Parser.Result Ormolu.Parser.Shebang
    Ormolu.Printer Ormolu.Printer.Combinators Ormolu.Printer.Comments
    Ormolu.Printer.Internal Ormolu.Printer.Meat.Common
    Ormolu.Printer.Meat.Declaration
    Ormolu.Printer.Meat.Declaration.Annotation
    Ormolu.Printer.Meat.Declaration.Class
    Ormolu.Printer.Meat.Declaration.Data
    Ormolu.Printer.Meat.Declaration.Default
    Ormolu.Printer.Meat.Declaration.Foreign
    Ormolu.Printer.Meat.Declaration.Instance
    Ormolu.Printer.Meat.Declaration.RoleAnnotation
    Ormolu.Printer.Meat.Declaration.Rule
    Ormolu.Printer.Meat.Declaration.Signature
    Ormolu.Printer.Meat.Declaration.Splice
    Ormolu.Printer.Meat.Declaration.Type
    Ormolu.Printer.Meat.Declaration.TypeFamily
    Ormolu.Printer.Meat.Declaration.Value
    Ormolu.Printer.Meat.Declaration.Warning
    Ormolu.Printer.Meat.ImportExport Ormolu.Printer.Meat.Module
    Ormolu.Printer.Meat.Pragma Ormolu.Printer.Meat.Type
    Ormolu.Printer.Operators Ormolu.Printer.SpanStream
    Ormolu.Processing.Common Ormolu.Processing.Cpp
    Ormolu.Processing.Postprocess Ormolu.Processing.Preprocess
    Ormolu.Utils

hidden-modules:       GHC GHC.DynFlags
import-dirs:          /usr/lib/ghc-9.0.2/site-local/fourmolu-0.3.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/fourmolu-0.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/fourmolu-0.3.0.0
hs-libraries:         HSfourmolu-0.3.0.0-2WinoTX2cM7BgDXOxBMTee
depends:
    HsYAML-0.2.1.0-FjNgLGOAnWiFOlzQhgz43c
    HsYAML-aeson-0.2.0.1-KMmZYxFpfohLQ4CuRoxND0
    aeson-1.5.6.0-BBhdcnlV5J5JNtwcCn5l4o base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1 directory-1.3.6.2
    dlist-1.0-F00OxiD1dC249OyRKVGlo2 exceptions-0.10.4 filepath-1.4.2.1
    ghc-lib-parser-8.10.5.20210606-7jpwkYARfluCRNplNhV1BZ mtl-2.2.2
    syb-0.7.2.1-IRarEg3pgAnIGKYwrA77mR text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-fourmolu/html/fourmolu.haddock
haddock-html:         /usr/share/doc/haskell-fourmolu/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
